{%- extends "admin/layout.html" -%}

{% block content %}
	<style type="text/css">
		a:link {
			color: #585858;
			text-decoration: none;
		}
		a:visited {
			text-decoration: none;
			color: #585858;
		}
		a:hover {
			text-decoration: none;
			color: #A4A4A4;
		}
		a:active {
			text-decoration: none;
			color: #A4A4A4;
		}
	</style>
	<!-- Content Wrapper. Contains page content -->
	<div class="content-wrapper">
		<!-- Main content -->
		<section class="content">
			<!-- Main row -->
			<div class="row">
				<!-- Left col -->
				<section class="col-lg-12 connectedSortable middle">
					<div class="box box-primary">
						<div class="box-header with-border">
							<h3 class="box-title">编辑角色</h3>
						</div>
						<form class="form" method="post" action="{{ url_for('admin.role_editsave') }}">
							<div class="box-body">
								{{ form.hidden_tag() }}
                                <input name="rid" type="hidden" value="{{ role.id }}">
                                {{ form.name.label }}
								{{ form.name(class="text form-control") }}<br>
                                {{ form.value.label }}
								{{ form.value(class="text form-control") }}<br>

							</div>
							<div class="box-footer">
								<input class="btn btn-primary" type="submit" name="submit" value="保存角色">
							</div>
						</form>
					</div>
				</section>
			</div>
		</section>
	</div>
{% endblock %}