/*!
 * Propeller v1.0.0 (http://propeller.in)
 * Copyright 2016-2017 Digicorp, Inc.
 * Licensed under MIT (http://propeller.in/LICENSE)
 */

.select2-container--bootstrap .select2-selection{ border:none; border-bottom: 1px solid #e6e6e6; box-shadow:none; border-radius:0; background-color:transparent;}
.select2-container--bootstrap .select2-selection--single{ padding:6px 24px 6px 0}
.select2-container--bootstrap.select2-container--focus .select2-selection, .select2-container--bootstrap.select2-container--open .select2-selection{ box-shadow:none; border-color:#e6e6e6;}
.select2-container--bootstrap .select2-selection--multiple .select2-search--inline .select2-search__field{padding: 0;}
.select2-container--bootstrap .select2-selection--multiple .select2-selection__choice{margin: 5px 5px 0 0; border: 1px solid #e6e6e6;}